Quick Start
===========

Installation
------------

KM3Pipe is written in Python, so all you need is a working Python installation
with version 2.7.x or above.

To install KM3Pipe, I recommend using ``pip`` (get it via ``easy_install pip``
if you don't have it already)::

    pip install km3pipe

This will pull the latest release from the PyPi repository.
To install the most recent development version, simply type

    pip install git+https://github.com/tamasgal/km3pipe@develop

To upgrade your existing installation::

    pip install --ugrade km3pipe


Additional Software Recommendations
-----------------------------------

I highly recommend using ``IPython`` for prototyping and playing around::

    pip install "ipython[notebook]"
